# Example: read truth-level particles  
# This example shows how to fill pT and Eta using single-electron sample
# Use Jas4pp to run this example.
# Nov 2, 2016. S.Chekanov (ANL)

from org.lcsim.lcio import LCIOReader
from hep.io.sio import SIOReader
from hep.lcio.implementation.sio import SIOLCReader
from hep.lcio.implementation.io import LCFactory
from hep.lcio.event import * 
from hep.lcio.io import *
from jhplot import *  # import graphics
from hephysics.particle import LParticle

# make list of files..
import glob
files=glob.glob("data/*.slcio")
factory = LCFactory.getInstance()
reader = factory.createLCReader()

nEvent=0
h1=H1D("pT",40,0,40)
h2=H1D("eta",40,-4,4)

for f in files:
  print "Open file=",f
  reader.open(f) 
  while(1):
    evt=reader.readNextEvent()
    if (evt == None): break
    nEvent=nEvent+1
    # print " file event: ",evt.getEventNumber(), " run=",evt.getRunNumber()
    if (nEvent%100==0): print "# Event: ",nEvent
    col = evt.getCollection("MCParticle")
    nMc=col.getNumberOfElements()
    particles=[]
    pp=0
    nn=0
    for i in range(nMc): # loop over all particles 
      par=col.getElementAt(i)
      if(par.getGeneratorStatus() == 1 and par.getCharge() !=0): 
              vertex = par.getVertex();
              pdg=par.getPDG()
              momentum = par.getMomentum() 
              ee=par.getEnergy()
              mass=par.getMass()
              px=momentum[0]
              py=momentum[1]
              pz=momentum[2]
              charge=par.getCharge()
              p=LParticle(px,py,pz,ee,mass) 
              p.setCharge(charge)
              particles.append(p)
              #print nn, "pdg=",pdg, " ",px,py,pz, " charge=",charge 
              nn=nn+1
    if (len(particles)>0):
       for i1 in range(len(particles)):
          p=particles[i1]
          h1.fill(p.perp())
          h2.fill(p.pseudoRapidity())

  reader.close() # close the file


c1=HPlot("MCparticle",800,400,2,1)
c1.visible()
c1.setAutoRange()
c1.setMarginLeft(90)
c1.setNameX("pT [GeV]")
c1.setNameY("Events")
c1.draw(h1)

c1.cd(2,1)
c1.setAutoRange()
c1.setMarginLeft(90)
c1.setNameX("&eta;")
c1.setNameY("Events")
c1.draw(h2)
c1.export("mc_truth_flat.pdf")
